---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Start it like '...'
2. use software or curl or bitcoin-cli like '....'
3. See the result and/or the logs

**Expected behavior**
A clear and concise description of what you expected to happen.


**Desktop (please complete the following information):**
 - which version do you use
 - What's your backend?
 - Which Database do you use?

**Additional context**
Add any other context about the problem here.
